@@ -17,6 +17,7 @@ from zope.interface.verify import verifyClass
 from unittest import TestCase, TestSuite, makeSuite
 from haufe.hrs.configuration.service import ConfigurationService
 from haufe.hrs.configuration.interfaces import IConfigurationService
+from haufe.hrs.configuration.util import DEFAULT_MARKER
 
 dirname = os.path.dirname(os.path.abspath(__file__))
 
@@ -38,7 +39,6 @@ class ServiceTests(TestCase):
         self.assertEqual(service.get('checkout_path', 'cms'), '/foo/bar')
         self.assertEqual(service.get('port', 'cms'), 777)
         self.assertEqual(service.get('databases.db1', 'cms'), 'n/a')
-        self.assertEqual(service.get('databases.db2', 'cms'), None)
 
     def testGetConfiguration(self):
         service = self._makeOne()
@@ -50,17 +50,17 @@ class ServiceTests(TestCase):
                     'cms.checkout_path' : '/foo/bar',
                     'cms.port' : 777,
                     'cms.databases.db1' : 'n/a',
-                    'cms.databases.db2' : None,
+                    'cms.databases.db2' : DEFAULT_MARKER,
                     'toolbox.active' : 0,
                    }
         self.assertEqual(got, expected)
 
-    def testGetConfigurationForPrefix(self):
+    def testGetConfigurationForDomain(self):
         service = self._makeOne()
         service.registerModel(os.path.join(dirname, 'model', 'cms.ini'))
         service.registerModel(os.path.join(dirname, 'model', 'toolbox.ini'))
         service.loadConfiguration(os.path.join(dirname, 'example-config.ini'))
-        got = service.getConfigurationForPrefix('toolbox')
+        got = service.getConfigurationForDomain('toolbox')
         expected = {'toolbox.active' : 0}
         self.assertEqual(got, expected)
 
